@@ -17,7 +17,10 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
+#define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
+#define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
 #define HAVE_CRT_EXTERNS_H 1
+#define HAVE_LIBDL 1
 #define HAVE_DIRENT_H 1
 #define HAVE__BOOL 1
 #define HAVE_STDBOOL_H 1
@@ -36,12 +39,12 @@
 #define HAVE_GRP_H 1
 #define HAVE_UTIME_H 1
 #define HAVE_SYS_RESOURCE_H 1
-#define HAVE_NETINET_IN_SYSTM_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_LANGINFO_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_TIME_H 1
 #define HAVE_SYS_SOCKET_H 1
+#define HAVE_MALLOC_MALLOC_H 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
 #define SIZEOF_INT 4
@@ -49,40 +52,59 @@
 #define SIZEOF_LONG 8
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
+#define SIZEOF___INT128 16
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
 #define SIZEOF_DOUBLE 8
 #define SIZEOF_TIME_T 8
+#define SIZEOF_CLOCK_T 8
 #define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
+#define SIGNEDNESS_OF_PID_T -1
 #define PIDT2NUM(v) INT2NUM(v)
 #define NUM2PIDT(v) NUM2INT(v)
 #define PRI_PIDT_PREFIX PRI_INT_PREFIX
 #define rb_uid_t uid_t
+#define SIGNEDNESS_OF_UID_T +1
 #define UIDT2NUM(v) UINT2NUM(v)
 #define NUM2UIDT(v) NUM2UINT(v)
 #define PRI_UIDT_PREFIX PRI_INT_PREFIX
 #define rb_gid_t gid_t
+#define SIGNEDNESS_OF_GID_T +1
 #define GIDT2NUM(v) UINT2NUM(v)
 #define NUM2GIDT(v) NUM2UINT(v)
 #define PRI_GIDT_PREFIX PRI_INT_PREFIX
 #define rb_time_t time_t
+#define SIGNEDNESS_OF_TIME_T -1
 #define TIMET2NUM(v) LONG2NUM(v)
 #define NUM2TIMET(v) NUM2LONG(v)
 #define PRI_TIMET_PREFIX PRI_LONG_PREFIX
 #define rb_dev_t dev_t
+#define SIGNEDNESS_OF_DEV_T -1
 #define DEVT2NUM(v) INT2NUM(v)
 #define NUM2DEVT(v) NUM2INT(v)
 #define PRI_DEVT_PREFIX PRI_INT_PREFIX
 #define rb_mode_t mode_t
+#define SIGNEDNESS_OF_MODE_T +1
 #define MODET2NUM(v) UINT2NUM(v)
 #define NUM2MODET(v) NUM2UINT(v)
 #define PRI_MODET_PREFIX PRI_INT_PREFIX
 #define rb_rlim_t rlim_t
+#define SIGNEDNESS_OF_RLIM_T +1
 #define RLIM2NUM(v) ULL2NUM(v)
 #define NUM2RLIM(v) NUM2ULL(v)
 #define PRI_RLIM_PREFIX PRI_LL_PREFIX
+#define rb_off_t off_t
+#define SIGNEDNESS_OF_OFF_T -1
+#define OFFT2NUM(v) LL2NUM(v)
+#define NUM2OFFT(v) NUM2LL(v)
+#define PRI_OFFT_PREFIX PRI_LL_PREFIX
+#define rb_clockid_t int
+#define SIGNEDNESS_OF_CLOCKID_T -1
+#define CLOCKID2NUM(v) INT2NUM(v)
+#define NUM2CLOCKID(v) NUM2INT(v)
+#define PRI_CLOCKID_PREFIX PRI_INT_PREFIX
 #define HAVE_PROTOTYPES 1
 #define TOKEN_PASTE(x,y) x##y
 #define STRINGIZE(expr) STRINGIZE0(expr)
@@ -96,8 +118,9 @@
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define UNREACHABLE __builtin_unreachable()
 #define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
+#define RUBY_FUNCTION_NAME_STRING __func__
 #define HAVE_DECL_SYS_NERR 1
-#define HAVE_LIBDL 1
+#define HAVE_DECL_GETENV 1
 #define SIZEOF_SIZE_T 8
 #define SIZEOF_PTRDIFF_T 8
 #define PRI_SIZE_PREFIX "z"
@@ -114,9 +137,9 @@
 #define HAVE_STRUCT_STAT_ST_MTIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_CTIMESPEC 1
 #define HAVE_STRUCT_TIMEVAL 1
+#define SIZEOF_STRUCT_TIMEVAL_TV_SEC SIZEOF_TIME_T
 #define HAVE_STRUCT_TIMESPEC 1
 #define HAVE_STRUCT_TIMEZONE 1
-#define HAVE_CLOCKID_T 1
 #define HAVE_RB_FD_INIT 1
 #define HAVE_INT8_T 1
 #define SIZEOF_INT8_T 1
@@ -134,6 +157,12 @@
 #define SIZEOF_INT64_T 8
 #define HAVE_UINT64_T 1
 #define SIZEOF_UINT64_T 8
+#define HAVE_INT128_T 1
+#define int128_t __int128
+#define SIZEOF_INT128_T SIZEOF___INT128
+#define HAVE_UINT128_T 1
+#define uint128_t unsigned __int128
+#define SIZEOF_UINT128_T SIZEOF_UNSIGNED___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -165,93 +194,94 @@
 #define HAVE_FFS 1
 #define SPT_TYPE SPT_REUSEARGV
 #define HAVE_SIGNBIT 1
+#define HAVE___SYSCALL 1
+#define HAVE__LONGJMP 1
+#define HAVE_CHROOT 1
+#define HAVE_CLOCK_GETTIME 1
+#define HAVE_COSH 1
+#define HAVE_DLOPEN 1
+#define HAVE_DUP 1
+#define HAVE_ENDGRENT 1
+#define HAVE_FCHMOD 1
+#define HAVE_FCHOWN 1
+#define HAVE_FCNTL 1
 #define HAVE_FMOD 1
+#define HAVE_FORK 1
+#define HAVE_FSYNC 1
+#define HAVE_FTRUNCATE 1
+#define HAVE_GETCWD 1
+#define HAVE_GETGRNAM_R 1
+#define HAVE_GETGROUPS 1
+#define HAVE_GETPGID 1
+#define HAVE_GETPGRP 1
+#define HAVE_GETPRIORITY 1
+#define HAVE_GETPWNAM_R 1
+#define HAVE_GETRLIMIT 1
+#define HAVE_GETSID 1
+#define HAVE_GETTIMEOFDAY 1
+#define HAVE_GMTIME_R 1
+#define HAVE_INITGROUPS 1
+#define HAVE_IOCTL 1
+#define HAVE_ISSETUGID 1
 #define HAVE_KILLPG 1
+#define HAVE_LCHMOD 1
+#define HAVE_LCHOWN 1
+#define HAVE_LINK 1
+#define HAVE_LLABS 1
+#define HAVE_LOCKF 1
+#define HAVE_LOG2 1
+#define HAVE_LSTAT 1
+#define HAVE_MALLOC_SIZE 1
+#define HAVE_MBLEN 1
+#define HAVE_MKTIME 1
+#define HAVE_POLL 1
+#define HAVE_POSIX_MEMALIGN 1
+#define HAVE_PREAD 1
+#define HAVE_READLINK 1
+#define HAVE_ROUND 1
+#define HAVE_SEEKDIR 1
+#define HAVE_SENDFILE 1
+#define HAVE_SETEGID 1
+#define HAVE_SETENV 1
+#define HAVE_SETEUID 1
+#define HAVE_SETGID 1
+#define HAVE_SETGROUPS 1
+#define HAVE_SETPGID 1
+#define HAVE_SETPGRP 1
+#define HAVE_SETREGID 1
+#define HAVE_SETREUID 1
+#define HAVE_SETRGID 1
+#define HAVE_SETRLIMIT 1
+#define HAVE_SETRUID 1
+#define HAVE_SETSID 1
+#define HAVE_SETUID 1
+#define HAVE_SHUTDOWN 1
+#define HAVE_SIGACTION 1
+#define HAVE_SIGALTSTACK 1
+#define HAVE_SIGPROCMASK 1
+#define HAVE_SINH 1
+#define HAVE_SYMLINK 1
+#define HAVE_SYSCALL 1
+#define HAVE_SYSCONF 1
+#define HAVE_TANH 1
+#define HAVE_TELLDIR 1
+#define HAVE_TIMEGM 1
+#define HAVE_TIMES 1
+#define HAVE_TRUNCATE 1
+#define HAVE_UNSETENV 1
+#define HAVE_UTIMENSAT 1
+#define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
-#define HAVE_FORK 1
-#define HAVE_SYSCALL 1
-#define HAVE___SYSCALL 1
-#define HAVE_CHROOT 1
-#define HAVE_GETCWD 1
-#define HAVE_TRUNCATE 1
-#define HAVE_FTRUNCATE 1
-#define HAVE_FTELLO 1
-#define HAVE_TIMES 1
-#define HAVE_UTIMES 1
-#define HAVE_UTIMENSAT 1
-#define HAVE_FCNTL 1
-#define HAVE_LOCKF 1
-#define HAVE_LSTAT 1
-#define HAVE_FSEEKO 1
-#define HAVE_LINK 1
-#define HAVE_SYMLINK 1
-#define HAVE_READLINK 1
-#define HAVE_READDIR_R 1
-#define HAVE_FSYNC 1
-#define HAVE_FCHOWN 1
-#define HAVE_SETITIMER 1
-#define HAVE_SETRUID 1
-#define HAVE_SETEUID 1
-#define HAVE_SETREUID 1
-#define HAVE_SOCKETPAIR 1
-#define HAVE_SETRGID 1
-#define HAVE_SETEGID 1
-#define HAVE_SETREGID 1
-#define HAVE_ISSETUGID 1
-#define HAVE_PAUSE 1
-#define HAVE_LCHOWN 1
-#define HAVE_LCHMOD 1
-#define HAVE_GETPGRP 1
-#define HAVE_SETPGRP 1
-#define HAVE_GETPGID 1
-#define HAVE_SETPGID 1
-#define HAVE_INITGROUPS 1
-#define HAVE_GETGROUPS 1
-#define HAVE_SETGROUPS 1
-#define HAVE_GETPRIORITY 1
-#define HAVE_GETRLIMIT 1
-#define HAVE_SETRLIMIT 1
-#define HAVE_SYSCONF 1
-#define HAVE_CLOSE 1
-#define HAVE_GETPWNAM_R 1
-#define HAVE_GETGRNAM_R 1
-#define HAVE_DLOPEN 1
-#define HAVE_SIGPROCMASK 1
-#define HAVE_SIGACTION 1
-#define HAVE_SIGSETJMP 1
-#define HAVE__LONGJMP 1
-#define HAVE_GETSID 1
-#define HAVE_SETSID 1
-#define HAVE_TELLDIR 1
-#define HAVE_SEEKDIR 1
-#define HAVE_FCHMOD 1
-#define HAVE_COSH 1
-#define HAVE_SINH 1
-#define HAVE_TANH 1
-#define HAVE_LOG2 1
-#define HAVE_ROUND 1
-#define HAVE_LLABS 1
-#define HAVE_SETUID 1
-#define HAVE_SETGID 1
-#define HAVE_SETENV 1
-#define HAVE_UNSETENV 1
-#define HAVE_MKTIME 1
-#define HAVE_TIMEGM 1
-#define HAVE_GMTIME_R 1
-#define HAVE_CLOCK_GETTIME 1
-#define HAVE_GETTIMEOFDAY 1
-#define HAVE_POLL 1
-#define HAVE_PREAD 1
-#define HAVE_SENDFILE 1
-#define HAVE_SHUTDOWN 1
-#define HAVE_SIGALTSTACK 1
-#define HAVE_DUP 1
-#define HAVE_POSIX_MEMALIGN 1
-#define HAVE_IOCTL 1
-#define RUBY_SETJMP(env) sigsetjmp(env,0)
-#define RUBY_LONGJMP(env,val) siglongjmp(env,val)
-#define RUBY_JMP_BUF sigjmp_buf
+#define HAVE_BUILTIN___BUILTIN_BSWAP16 1
+#define HAVE_BUILTIN___BUILTIN_BSWAP32 1
+#define HAVE_BUILTIN___BUILTIN_BSWAP64 1
+#define HAVE_BUILTIN___BUILTIN_CLZ 1
+#define HAVE_BUILTIN___BUILTIN_CLZL 1
+#define HAVE_BUILTIN___BUILTIN_CLZLL 1
+#define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
+#define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
+#define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
@@ -279,11 +309,19 @@
 #define HAVE_PTHREAD_COND_INIT 1
 #define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
+#define HAVE_PTHREAD_SETNAME_NP 1
 #define HAVE_PTHREAD_ATTR_INIT 1
+#define SET_THREAD_NAME(name) pthread_setname_np(name)
+#define HAVE_EXECINFO_H 1
+#define HAVE_LIBUNWIND_H 1
 #define HAVE_BACKTRACE 1
+#define BROKEN_BACKTRACE 1
 #define DLEXT_MAXLEN 7
 #define DLEXT ".bundle"
 #define LIBDIR_BASENAME "lib"
+#define RUBY_SETJMP(env) sigsetjmp((env),0)
+#define RUBY_LONGJMP(env,val) siglongjmp((env),val)
+#define RUBY_JMP_BUF sigjmp_buf
 #define HAVE_PTHREAD_H 1
-#define RUBY_EXEC_PREFIX "/opt/local"
+#define RUBY_PLATFORM "x86_64-darwin17"
 #endif /* INCLUDE_RUBY_CONFIG_H */
